diff src/notify.h @ 5476:9bcd8cd625ae

[gaim-migrate @ 5872] Some little tidy-ups. committer: Tailor Script <tailor@pidgin.im>
author Christian Hammond <chipx86@chipx86.com>
date Thu, 22 May 2003 05:23:14 +0000
parents 0031a613a87d
children 3c7748b24410
line wrap: on
line diff
--- a/src/notify.h	Thu May 22 01:31:56 2003 +0000
+++ b/src/notify.h	Thu May 22 05:23:14 2003 +0000
@@ -65,7 +65,7 @@
 						   const char **urls, GCallback cb,
 						   void *user_data);
 
-	void (*close_notify)(GaimNotifyType type, void *uihandle);
+	void (*close_notify)(GaimNotifyType type, void *ui_handle);
 
 } GaimNotifyUiOps;
 
@@ -138,10 +138,10 @@
  * This should be used only by the UI operation functions and part of the
  * core.
  *
  * @param type     The notification type.
  * @param uihandle The notification UI handle.
  */
-void gaim_notify_close(GaimNotifyType type, void *uihandle);
+void gaim_notify_close(GaimNotifyType type, void *ui_handle);
 
 /**
  * Closes all notifications registered with the specified handle.
@@ -138,10 +138,10 @@
  * core.
  *
- * @param type     The notification type.
- * @param uihandle The notification UI handle.
+ * @param type      The notification type.
+ * @param ui_handle The notification UI handle.
  */